@@ -13,7 +13,7 @@ class MiscHelperTest extends TestCaseCompat
      */
     public function split_seconds_microseconds($input, $expected)
     {
-        $this->assertEquals($expected, MiscHelper::splitSecondsMicroseconds($input));
+        self::assertEquals($expected, MiscHelper::splitSecondsMicroseconds($input));
     }
 
     /**
@@ -22,7 +22,7 @@ class MiscHelperTest extends TestCaseCompat
      */
     public function hexdump($args, $expected)
     {
-        $this->assertRegExp($expected, MiscHelper::hexdump($args[0], $args[1], $args[2], $args[3]));
+        self::assertPattern($expected, MiscHelper::hexdump($args[0], $args[1], $args[2], $args[3]));
     }
 
     /**
@@ -30,10 +30,10 @@ class MiscHelperTest extends TestCaseCompat
      */
     public function method_sig()
     {
-        $this->assertEquals('test', MiscHelper::methodSig('test'));
+        self::assertEquals('test', MiscHelper::methodSig('test'));
     }
 
-    public function splitSecondsMicrosecondsData()
+    public function splitSecondsMicrosecondsData(): array
     {
         return [
             [0, [0, 0]],
@@ -50,7 +50,7 @@ class MiscHelperTest extends TestCaseCompat
         ];
     }
 
-    public function hexdumpData()
+    public function hexdumpData(): array
     {
         return [
             [['FM', false, false, true], '/000\s+46 4d\s+FM/'],
